##  Facet Keys
**Note**
This document doesn't provide a comprehensive list of all available filter options. You can view a full list of filters and facet keys in the GraphQL schema, accessible through the GraphiQL tool in your SAP LeanIX workspace. Explore filter options for each query in the Explorer section of GraphiQL and apply them interactively to your operations.
Facets are a powerful feature that enhances the precision of data filtering operations. They are the keys used to filter results in queries. These keys can be based on various attributes, such as the fact sheet type, the relation between fact sheets, and more.
Given the diverse nature of fact sheets in SAP LeanIX, facets fall into two categories:
  * [Global facet keys](https://help.sap.com/docs/leanix/ea/filtering-in-graphql?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a2edc7a441014bb70948cb326e764__global_facet_keys)
  * [Facet keys specific to fact sheet types](https://help.sap.com/docs/leanix/ea/filtering-in-graphql?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a2edc7a441014bb70948cb326e764__facet_keys_specific_to_fact_sheet_types)


This categorization ensures you can apply the most appropriate and relevant filters to your data.
